@@ -86,7 +86,7 @@ def list(search: str = typer.Argument("")):
     try:
         create_file_if_not_exists()
         start_time = current_milli_time()
-        os.system('source ~/.bash_profile')
+        os.system('source ~/.bash_profile &')
         # 这里暂存到临时文件中，避免控制台输出
         os.system('adb forward tcp:19091 tcp:19191 > temp.log')
 
